@@ -1,4 +1,4 @@
-bd.groups.optim<- function (phy, S,xcut=0) 
+bd.groups.optim<-function(phy,S,xcut=0,lambda=0,mu=0) 
 {
     if (class(phy) != "phylo") 
         stop("object \"phy\" is not of class \"phylo\"")
@@ -20,11 +20,14 @@ bd.groups.optim<- function (phy, S,xcut=0)
  		p1 <- function(t,l,m){ (l-m)^2 * exp(-(l-m)*t)/(l-m*exp(-(l-m)*t))^2 }
  		if (xcut>0){trm.br<-trm.br*0+xcut}
  		#print(trm.br)
- 		res<- -( (N-2)*log(l)+2*log(p1(x[1],l,m))-2*log(1-m*p0m(x[1],l,m))+sum(log(p1(x[2:(N-1)],l,m)))+sum((S[1:N]-1)*log(l*p0m(trm.br[1:N],l,m))))}
+ 		res<- -( (N-2)*log(2*l)+2*log(p1(x[1],l,m))+sum(log(p1(x[2:(N-1)],l,m)))+sum((S[1:N]-1)*log(2*l*p0m(trm.br[1:N],l,m))))
+ 		#res<- res -2*log(1-m*p0m(x[1],l,m))
+ 		}
  		res
     }
+    if (lambda>0) {final<-dev(c(mu/lambda,lambda-mu)) } else {
     out <- subplex( c(0, 0.2),dev, hessian = TRUE)
     res<-bd.groups.conf(out,dev)
-    final<-list(res,out)
+    final<-list(res,out)}
     final
     }
